@@ -1,6 +1,4 @@
-use std::collections::HashMap;
 use std::path::PathBuf;
-use std::process::{Command, Stdio};
 
 use anyhow::{anyhow, Context,  Result};
 use clap::value_t;
@@ -16,7 +14,7 @@ use crate::gitlab::{Client, CreateMergeRequest, Query};
 use crate::gitlab::Issue as GLIssue;
 use crate::gitlab::Branch as GLBranch;
 use crate::gitlab::CreateBranch as GLCreateBranch;
-use crate::mr::MergeRequest;
+use crate::mr::{checkout_mr, MergeRequest};
 use crate::utils;
 
 #[derive(GraphQLQuery)]
@@ -577,24 +575,9 @@ pub fn create_merge_request_cmd(
     }
 
     if args.occurrences_of("assignees") > 0 {
-        let mut config_member_map = config.members  // these look like ["1234:name", ...]
-            .iter()
-            .map(|x|
-                (x.split(':').collect::<Vec<&str>>()[1],
-                x.split(':').collect::<Vec<&str>>()[0].parse::<u64>().unwrap())
-                )
-            .collect::<HashMap<&str, u64>>();  // ... and end up like {"name": 1234, ...}
 
-        let assignee_ids = args.values_of("assignees").unwrap()
-            .map(|n| config_member_map.remove(n).ok_or_else(|| n))
-            .collect::<anyhow::Result<Vec<u64>, &str>>();
-
-        debug!("config_member_map: {:#?}", config_member_map);
-        debug!("assignee_ids: {:#?}", assignee_ids);
-
-        let final_ids = assignee_ids
-            .map_err(|e| anyhow!("Assignee `{}` not found. If user is a project member, run `git lab project refresh` ", e))?;
-        endpoint.assignees(final_ids.into_iter());
+        let assignee_ids = utils::map_user_ids_from_names(&config.members, args.values_of("assignees").unwrap())?;
+        endpoint.assignees(assignee_ids.into_iter());
 
     } else {
         // pull the cached project member names out of config and present them
@@ -642,19 +625,7 @@ pub fn create_merge_request_cmd(
     println!("Merge Request created at: {}", merge_request.web_url);
 
     if args.occurrences_of("checkout") > 0 {
-        Command::new("git")
-            .args(&["fetch","origin"])
-            .stdout(Stdio::inherit())
-            .stderr(Stdio::inherit())
-            .spawn()?
-            .wait()?;
-
-        Command::new("git")
-            .args(&["checkout","-b", &source_branch, &("origin/".to_string() + &source_branch)])
-            .stdout(Stdio::inherit())
-            .stderr(Stdio::inherit())
-            .spawn()?
-            .wait()?;
+        checkout_mr(&source_branch)?;
     }
 
     Ok(())
